# $Id: MoviePosterDB.pm 3570 2010-01-03 21:43:00Z chris $

package WebService::MoviePosterDB;

use strict;
use warnings;

our $VERSION = '0.01';

use JSON;
use LWP::UserAgent;
use URI;

use WebService::MoviePosterDB::Movie;

sub new {
    my $class = shift;
    my %args = @_;
    my $self = {};
    
    bless $self, $class;
    
    $self->{'api_key'} = $args{'api_key'} || "demo";
    $self->{'api_secret'} = $args{'api_secret'} || "demo";
    
    return $self;
}


# In the fullness of time, the intention is to use the proper MoviePosterDB api, 
# accessed via http://api.movieposterdb.com/json, but until the mechanism for
# generating the secret hash is known, we use the old api, 
# http://api.movieposterdb.com/json.inc.php, and translate the parameters.

sub search {
    my $self = shift;
    my %args = @_;
    
    my $web_service_uri = URI->new();

    $web_service_uri->scheme("http");
    $web_service_uri->host("api.movieposterdb.com");
    $web_service_uri->path("json.inc.php");
    
    my $url = $web_service_uri->as_string();

    {
	# TODO: Validate these against a permitted list + perform url encoding as appropriate
	my $f = 1;
	foreach (keys %args) {
	    my ($k, $v) = ($_, $args{$_});
	    
	    # Fixup to make json.inc.php look like json
	    if ($k eq "imdb_code") {
		$k = "imdb";
	    } elsif ($k eq "title" || $k eq "width") {
		# Nothing
	    } else {
		next;
	    }

	    $url .= ($f ? "?" : "&") . $k . "=" . $v;
	    undef $f;
	}
    }

    my $ua = LWP::UserAgent->new();
    $ua->env_proxy();
    
    $ua->agent("WebService::MoviePosterDB/$VERSION");
    
    my $response = $ua->get($url);
    
    if($response->code() eq "200") {
	my $json = new JSON;

	return WebService::MoviePosterDB::Movie->_new($json->decode($response->content));

    }
    
    die "URL (", $url, ") Request Failed - Code: ", $response->code(), " Error: ", $response->message(), "\n";

}

sub imdb {
    return (shift)->{'_content'}->{'imdb'};
}

sub title {
    return (shift)->{'_content'}->{'title'};
}

sub year  {
    return (shift)->{'_content'}->{'year'};
}

sub page {
    return (shift)->{'_content'}->{'page'};
}

sub posters {
    # TODO: Parse and return OO content.
    return (shift)->{'_content'}->{'posters'};
}
1;
